@@ -23,7 +23,6 @@ extern "C" {
 
 #include <libdrm/drm_fourcc.h>
 
-#include "pipewireproduce_p.h"
 #include "vaapiutils_p.h"
 
 #include "logging_record.h"
@@ -176,6 +175,38 @@ void Encoder::setQuality(std::optional<quint8> quality)
     }
 }
 
+bool Encoder::supportsHardwareEncoding()
+{
+    return !VaapiUtils::instance()->devicePath().isEmpty();
+}
+
+void Encoder::setEncodingPreference(PipeWireBaseEncodedStream::EncodingPreference preference)
+{
+    m_encodingPreference = preference;
+}
+
+void Encoder::applyEncodingPreference(AVDictionary *options)
+{
+    switch (m_encodingPreference) {
+    case PipeWireBaseEncodedStream::EncodingPreference::NoPreference:
+        av_dict_set(&options, "preset", "veryfast", 0);
+        break;
+    case PipeWireBaseEncodedStream::EncodingPreference::Quality:
+        av_dict_set(&options, "preset", "medium", 0);
+        break;
+    case PipeWireBaseEncodedStream::EncodingPreference::Speed:
+        av_dict_set(&options, "preset", "ultrafast", 0);
+        av_dict_set(&options, "tune", "zerolatency", 0);
+        break;
+    case PipeWireBaseEncodedStream::EncodingPreference::Size:
+        av_dict_set(&options, "preset", "slow", 0);
+        break;
+    default: //  Same as NoPreference
+        av_dict_set(&options, "preset", "veryfast", 0);
+        break;
+    }
+}
+
 SoftwareEncoder::SoftwareEncoder(PipeWireProduce *produce)
     : Encoder(produce)
 {
@@ -192,8 +223,8 @@ bool SoftwareEncoder::filterFrame(const PipeWireFrame &frame)
             m_produce->m_stream->renegotiateModifierFailed(frame.format, frame.dmabuf->modifier);
             return false;
         }
-    } else if (frame.image) {
-        image = frame.image.value();
+    } else if (frame.dataFrame) {
+        image = frame.dataFrame->toImage();
     } else {
         return false;
     }
@@ -283,7 +314,7 @@ bool SoftwareEncoder::createFilterGraph(const QSize &size)
     outputs->pad_idx = 0;
     outputs->next = nullptr;
 
-    ret = avfilter_graph_parse(m_avFilterGraph, "format=pix_fmts=yuv420p", outputs, inputs, NULL);
+    ret = avfilter_graph_parse(m_avFilterGraph, m_filterGraphToParse.toUtf8().data(), outputs, inputs, NULL);
     if (ret < 0) {
         qCWarning(PIPEWIRERECORD_LOGGING) << "Failed creating filter graph";
         return false;
@@ -322,11 +353,6 @@ bool HardwareEncoder::filterFrame(const PipeWireFrame &frame)
 
     auto attribs = frame.dmabuf.value();
 
-    if (!m_supportsHardwareModifiers && attribs.modifier != 0) {
-        m_produce->m_stream->renegotiateModifierFailed(frame.format, attribs.modifier);
-        return false;
-    }
-
     auto drmFrame = av_frame_alloc();
     if (!drmFrame) {
         qFatal("Failed to allocate memory");
@@ -371,26 +397,25 @@ bool HardwareEncoder::filterFrame(const PipeWireFrame &frame)
 
 QByteArray HardwareEncoder::checkVaapi(const QSize &size)
 {
-    VaapiUtils utils;
-    if (utils.devicePath().isEmpty()) {
+    auto utils = VaapiUtils::instance();
+    if (utils->devicePath().isEmpty()) {
         qCWarning(PIPEWIRERECORD_LOGGING) << "Hardware encoding is not supported on this device.";
         return QByteArray{};
     }
 
-    auto minSize = utils.minimumSize();
+    auto minSize = utils->minimumSize();
     if (size.width() < minSize.width() || size.height() < minSize.height()) {
         qCWarning(PIPEWIRERECORD_LOGGING) << "Requested size" << size << "less than minimum supported hardware size" << minSize;
         return QByteArray{};
     }
 
-    auto maxSize = utils.maximumSize();
+    auto maxSize = utils->maximumSize();
     if (size.width() > maxSize.width() || size.height() > maxSize.height()) {
         qCWarning(PIPEWIRERECORD_LOGGING) << "Requested size" << size << "exceeds maximum supported hardware size" << maxSize;
         return QByteArray{};
     }
-    m_supportsHardwareModifiers = utils.supportsHardwareModifiers();
 
-    return utils.devicePath();
+    return utils->devicePath();
 }
 
 bool HardwareEncoder::createDrmContext(const QSize &size)
